package com.ruoyi.project.business.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.ruoyi.project.business.domain.TpAreaBasicPrice;
import com.ruoyi.project.business.domain.TpAreaOptionalPara;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 【请填写功能名称】Mapper接口
 * 
 * @author ruoyi
 * @date 2024-05-28
 */
public interface TpAreaOptionalParaMapper extends BaseMapper<TpAreaOptionalPara>
{
    /**
     * 查询【请填写功能名称】
     * 
     * @param id 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    public TpAreaOptionalPara selectTpAreaOptionalParaById(Long id);

    /**
     * 查询【请填写功能名称】列表
     * 
     * @param tpAreaOptionalPara 【请填写功能名称】
     * @return 【请填写功能名称】集合
     */
    public List<TpAreaOptionalPara> selectTpAreaOptionalParaList(TpAreaOptionalPara tpAreaOptionalPara);

    /**
     * 新增【请填写功能名称】
     * 
     * @param tpAreaOptionalPara 【请填写功能名称】
     * @return 结果
     */
    public int insertTpAreaOptionalPara(TpAreaOptionalPara tpAreaOptionalPara);

    /**
     * 修改【请填写功能名称】
     * 
     * @param tpAreaOptionalPara 【请填写功能名称】
     * @return 结果
     */
    public int updateTpAreaOptionalPara(TpAreaOptionalPara tpAreaOptionalPara);

    /**
     * 删除【请填写功能名称】
     * 
     * @param id 【请填写功能名称】主键
     * @return 结果
     */
    public int deleteTpAreaOptionalParaById(Long id);

    /**
     * 批量删除【请填写功能名称】
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTpAreaOptionalParaByIds(Long[] ids);

    void deleteTpAreaOptionalParaByElevatorModelId(@Param("id") Long id);
}
