package com.ruoyi.project.business.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.framework.annotation.DataUpdateCheck;
import com.ruoyi.project.business.domain.TpAreaOptionalPara;
import com.ruoyi.project.business.service.ITpAreaOptionalParaService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.framework.aspectj.lang.annotation.Log;
import com.ruoyi.framework.aspectj.lang.enums.BusinessType;
import com.ruoyi.framework.web.controller.BaseController;
import com.ruoyi.framework.web.domain.AjaxResult;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.framework.web.page.TableDataInfo;

/**
 * 【请填写功能名称】Controller
 * 
 * @author ruoyi
 * @date 2024-05-28
 */
@RestController
@RequestMapping("/business/areaOption/para")
public class TpAreaOptionalParaController extends BaseController
{
    @Autowired
    private ITpAreaOptionalParaService tpAreaOptionalParaService;

    /**
     * 查询【请填写功能名称】列表
     */
    // @PreAuthorize("@ss.hasPermi('system:para:list')")
    @GetMapping("/list")
    public TableDataInfo list(TpAreaOptionalPara tpAreaOptionalPara)
    {
        startPage();
        List<TpAreaOptionalPara> list = tpAreaOptionalParaService.selectTpAreaOptionalParaList(tpAreaOptionalPara);
        return getDataTable(list);
    }

    /**
     * 导出【请填写功能名称】列表
     */
    // @PreAuthorize("@ss.hasPermi('system:para:export')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TpAreaOptionalPara tpAreaOptionalPara)
    {
        List<TpAreaOptionalPara> list = tpAreaOptionalParaService.selectTpAreaOptionalParaList(tpAreaOptionalPara);
        ExcelUtil<TpAreaOptionalPara> util = new ExcelUtil<TpAreaOptionalPara>(TpAreaOptionalPara.class);
        util.exportExcel(response, list, "【请填写功能名称】数据");
    }

    /**
     * 获取【请填写功能名称】详细信息
     */
    // @PreAuthorize("@ss.hasPermi('system:para:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tpAreaOptionalParaService.selectTpAreaOptionalParaById(id));
    }

    @GetMapping(value = "/getOptionParaSelection/{id}")
    public AjaxResult getOptionParaSelection(@PathVariable("id") Long id)
    {
        return success(tpAreaOptionalParaService.getOptionParaSelection(id));
    }

    /**
     * 新增【请填写功能名称】
     */
    // @PreAuthorize("@ss.hasPermi('system:para:add')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TpAreaOptionalPara tpAreaOptionalPara)
    {
        return toAjax(tpAreaOptionalParaService.insertTpAreaOptionalPara(tpAreaOptionalPara));
    }

    /**
     * 修改【请填写功能名称】
     */
    // @PreAuthorize("@ss.hasPermi('system:para:edit')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.UPDATE)
    @PutMapping
    @DataUpdateCheck(key = "id", tableName = "tp_area_optional_para")
    public AjaxResult edit(@RequestBody TpAreaOptionalPara tpAreaOptionalPara)
    {
        return toAjax(tpAreaOptionalParaService.updateTpAreaOptionalPara(tpAreaOptionalPara));
    }

    @Log(title = "【切换状态】", businessType = BusinessType.UPDATE)
    @PutMapping("toggleStatus")
    public AjaxResult toggleStatus(@RequestBody TpAreaOptionalPara tpAreaOptionalPara)
    {
        TpAreaOptionalPara update = new TpAreaOptionalPara();
        update.setId(tpAreaOptionalPara.getId());
        update.setStatus(tpAreaOptionalPara.getStatus());
        return toAjax(tpAreaOptionalParaService.updateTpAreaOptionalPara(update));
    }

    /**
     * 删除【请填写功能名称】
     */
    // @PreAuthorize("@ss.hasPermi('system:para:remove')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tpAreaOptionalParaService.deleteTpAreaOptionalParaByIds(ids));
    }
}
